/* eslint-disable */
/**
 * nano-markdown - a minimal markdown to html converter
 * Copyright (c) 2015, Vladimir Antonov. (MIT Licensed)
 * https://github.com/Holixus/nano-markdown
 */

// Removed IIFE

"use strict";

import { useMemo } from "react";

const escapes = '\\[!]#{()}*+-._';
const esc_ofs = 16;

function lex(a) {
    return a.replace(/\\([(){}[\]#*+\-.!_\\])/g, function (_, ch) {
        return String.fromCharCode(1, escapes.indexOf(ch) + esc_ofs);
    }).replace(/(\*\*|__|~~)(.*?)\1/g, function (_, delim, text) {
        return (delim === '~~') ? '<del>' + text + '</del>' : '<b>' + text + '</b>';
    // @ts-ignore
    }).replace(/(\n|^|\W)([_\*])(.*?)\2(\W|$|\n)/g, function (_, l, di, ital, r) {
        return l + '<i>' + ital + '</i>' + r;
    }).replace(/(!?)\[([^\]<>]+)\]\((\+?)([^ \)<>]+)(?: "([^\(\)\"]+)")?\)/g, function (_, is_img, text, new_tab, ref, title) {
        let attrs = title ? ' title="' + title + '"' : '';
        if (is_img)
            return '<img src="' + nmd.href(ref) + '" alt="' + text + '"' + attrs + '/>';
        if (new_tab)
            attrs += ' target="_blank" rel="noopener"';
        return '<a href="' + nmd.href(ref) + '"' + attrs + '>' + text + '</a>';
    });
}

function unesc(a) {
    return a.replace(/\x01([\x0f-\x1c])/g, function (_, c) {
        return escapes.charAt(c.charCodeAt(0) - esc_ofs);
    });
}

const nmd = function (md) {
    return md.replace(/.+(?:\n.+)*/g, function (m) {
        const code = /^\s{4}([^]*)$/.exec(m);
        if (code)
            return '<pre><code>' + code[1].replace(/\n    /g, '\n') + '</code></pre>';
        const ps:any[] = []
        let cur:any = null
        const rows = lex(m).split('\n');
        for (let i = 0, l = rows.length; i < l; ++i) {
            const row = rows[i],
                head = /^\s{0,3}(\#{1,6})\s+(.*?)\s*#*\s*$/.exec(row);
            if (head) {
                ps.push(cur = [head[2], 'h', head[1].length]);
                continue;
            }
            const list = /^(\s*)(?:[-*]|(\d[.)])) (.+)$/.exec(row);
            if (list)
                ps.push(cur = [list[3], list[2] ? 'ol' : 'ul', list[1].length]);
            else if (/^\s{0,3}([-])(\s*\1){2,}\s*$/.test(row))
                ps.push(cur = ['', 'hr']);
            else if (cur && cur[1] !== 'hr' && cur[1] !== 'h')
                cur[0] += '\n' + row;
            else
                ps.push(cur = [row, 'span', '']);
        }
        let out = '', lists:any = [];
        for (let i = 0, l = ps.length; i < l; ++i) {
            cur = ps[i];
            const text = cur[0], tag = cur[1], lvl = cur[2];
            if (tag === 'ul' || tag === 'ol') {
                if (!lists.length || lvl > lists[0][1]) {
                    lists.unshift([tag, lvl]);
                    out += '<' + lists[0][0] + '><li>' + text;
                } else if (lists.length > 1 && lvl <= lists[1][1]) {
                    out += '</li></' + lists.shift()[0] + '>';
                    --i;
                } else
                    out += '</li><li>' + text;
            } else {
                while (lists.length)
                    out += '</li></' + lists.shift()[0] + '>';
                out += (tag === 'hr') ? '<hr/>' : '<' + tag + lvl + nmd.headAttrs() + '>' + text + '</' + tag + lvl + '>';
            }
        }
        while (lists.length)
            out += '</li></' + lists.shift()[0] + '>';
        return unesc(out);
    });
};

nmd.href = function (ref) {
    return ref;
};

nmd.headAttrs = function () {
    return '';
};

export function useMarkdownToHTML(markdown) {
    return useMemo(() => nmd(markdown), [markdown]);
}
