import React from 'react';

import {
  TableContainer,
  Table,
  TableCaption,
  TableHead,
  TableRow,
  TableBody,
  TableHeadCell,
  TableDataCell,
  TableNoDataRow,
  TableSortLabel,
} from '@digigov/ui/content/Table';
import { useSort } from '@digigov/ui/content/Table/hooks/useSort';

const headerConfig = [
  {
    name: 'product',
    label: 'Προϊόν',
    sortLabels: {
      asc: 'Αλφαβητική σειρά (Α -> Ω)',
      desc: 'Αλφαβητική σειρά (Ω -> Α)',
    },
  },
  {
    name: 'price',
    label: 'Τιμή',
    sortLabels: {
      asc: 'Αύξουσα σειρά',
      desc: 'Φθίνουσα σειρά',
    },
  },
  {
    name: 'stock',
    label: 'Στοκ',
    sortLabels: {
      asc: 'Αύξουσα σειρά',
      desc: 'Φθίνουσα σειρά',
    },
  },
  {
    name: 'date',
    label: 'Ημερομηνία',
    sortLabels: {
      asc: 'Αύξουσα σειρά',
      desc: 'Φθίνουσα σειρά',
    },
  },
];

const data = [
  {
    id: 1,
    product: 'Τυρί',
    price: '4.9€',
    stock: 20,
    date: '2013-04-01',
  },
  {
    id: 2,
    product: 'Γάλα',
    price: '1.9€',
    stock: 32,
    date: '2013-01-01',
  },
  {
    id: 3,
    product: 'Γιαούρτι',
    price: '2.4€',
    stock: 12,
    date: '2002-04-12',
  },
  {
    id: 4,
    product: 'Κρέμα',
    price: '3.9€',
    stock: 8,
    date: '2011-12-12',
  },
  {
    id: 5,
    product: 'Βούτυρο',
    price: '0.9€',
    stock: 99,
    date: '2019-06-01',
  },
  {
    id: 6,
    product: 'Καφές',
    price: '2.9€',
    stock: 86,
    date: '2023-02-11',
  },
  {
    id: 7,
    product: 'Ψωμί',
    price: '99€',
    stock: 12,
    date: '2000-12-12',
  },
];

export const WithSortFilters = () => {
  const { sortedData, setSortedField, field, direction } = useSort(data);

  return (
    <TableContainer>
      <Table>
        <TableCaption>Πίνακας προϊόντων</TableCaption>
        <TableHead>
          <TableRow>
            {headerConfig.map((header, index) => {
              return (
                <TableHeadCell key={index}>
                  <TableSortLabel
                    labels={header.sortLabels}
                    onSort={(dir) => setSortedField(header.name, dir)}
                    direction={header.name === field ? direction : 0}
                  >
                    {header.label}
                  </TableSortLabel>
                </TableHeadCell>
              );
            })}
          </TableRow>
        </TableHead>
        <TableBody>
          {sortedData.length > 0 ? (
            sortedData.map((d, index) => {
              return (
                <TableRow key={index}>
                  <TableDataCell>{d.product}</TableDataCell>
                  <TableDataCell>{d.price}</TableDataCell>
                  <TableDataCell>{d.stock}</TableDataCell>
                  <TableDataCell>
                    {new Date(d.date).toLocaleDateString('en-GB')}
                  </TableDataCell>
                </TableRow>
              );
            })
          ) : (
            <TableNoDataRow>Δεν υπρχουν δεδομένα</TableNoDataRow>
          )}
        </TableBody>
      </Table>
    </TableContainer>
  );
};
export default WithSortFilters;
