import React from 'react';
import NavList from '@digigov/react-core/NavList';
import NavListItemAction from '@digigov/react-core/NavListItemAction';
import NavMenuContainer from '@digigov/react-core/NavMenuContainer';
import NavMenuContent from '@digigov/react-core/NavMenuContent';
import NavMenuContentListItem from '@digigov/react-core/NavMenuContentListItem';
import NavMenuTitle from '@digigov/react-core/NavMenuTitle';
import { Link } from '@digigov/ui/navigation/Link';
import { useNavList } from '@digigov/ui/navigation/NavList/hooks/useNavList';
import Nav from '@digigov/ui/navigation/NavList/Nav';
import NavMenuContentList from '@digigov/ui/navigation/NavList/NavMenuContentList';
import { NavListAutoProps } from '@digigov/ui/navigation/NavList/types';

export const NavListAuto: React.FC<NavListAutoProps> = ({
  layout,
  links = [],
  ...props
}) => {
  const { registerNavItemMenu, registerNavItem } = useNavList();

  return (
    <Nav {...props}>
      <NavList layout={layout}>
        {links.map((item, key) => (
          <React.Fragment key={key}>
            <NavListItemAction {...registerNavItem(item)}>
              {item.label}
            </NavListItemAction>
            {item.subMenu && (
              <NavMenuContainer
                layout={layout}
                {...registerNavItemMenu(item.name)}
              >
                {(item.subMenuHeading || item.label) && (
                  <NavMenuTitle>
                    {item.subMenuHeading || item.label}
                  </NavMenuTitle>
                )}
                <NavMenuContent>
                  <NavMenuContentList role="menu">
                    {item.subMenu?.map((subMenu, menuIndex) => {
                      return (
                        subMenu?.href && (
                          <NavMenuContentListItem
                            key={menuIndex}
                            role="presentation"
                          >
                            <Link
                              role="menuitem"
                              id={subMenu.name}
                              href={subMenu.href}
                            >
                              {subMenu.label}
                            </Link>
                          </NavMenuContentListItem>
                        )
                      );
                    })}
                  </NavMenuContentList>
                </NavMenuContent>
              </NavMenuContainer>
            )}
          </React.Fragment>
        ))}
      </NavList>
    </Nav>
  );
};

export default NavListAuto;
