import React from 'react';
import {
  SummaryList,
  SummaryListItem,
  SummaryListItemKey,
  SummaryListItemValue,
  SummaryListItemAction,
} from '@digigov/ui/content/SummaryList';
import { Link } from '@digigov/ui/navigation/Link';
import {
  Tabs,
  TabsHeading,
  TabsList,
  useTabs,
} from '@digigov/ui/navigation/Tabs';
import { TabsListItem, TabsPanel } from '@digigov/ui/navigation/Tabs/auto';
import { Heading } from '@digigov/ui/typography/Heading';
import { Paragraph } from '@digigov/ui/typography/Paragraph';
import { VisuallyHidden } from '@digigov/ui/utils/VisuallyHidden';

export function Default() {
  const { register, panel } = useTabs({ defaultOpen: 'a' });
  return (
    <Tabs>
      <TabsHeading size="md">Περιεχόμενα</TabsHeading>
      <TabsList>
        <TabsListItem {...register('a')}>Στοιχεία πολίτη</TabsListItem>
        <TabsListItem {...register('b')}>Yποθέσεις</TabsListItem>
        <TabsListItem {...register('c')}>Μηνύματα</TabsListItem>
        <TabsListItem {...register('d')}>Ιστορικό</TabsListItem>
      </TabsList>
      <TabsPanel {...panel('a')}>
        <Heading size="md" element="h3">
          Στοιχεία πολίτη
        </Heading>
        <SummaryList>
          <SummaryListItem>
            <SummaryListItemKey>Όνομα</SummaryListItemKey>
            <SummaryListItemValue>Γιώργος Παπαδόπουλος</SummaryListItemValue>
            <SummaryListItemAction>
              {' '}
              <Link href="#">
                Αλλαγή <VisuallyHidden> ονόματος </VisuallyHidden>
              </Link>
            </SummaryListItemAction>
          </SummaryListItem>
          <SummaryListItem>
            <SummaryListItemKey>Ημ. Γέννησης</SummaryListItemKey>
            <SummaryListItemValue>11 Μαϊου 1990</SummaryListItemValue>
          </SummaryListItem>
          <SummaryListItem>
            <SummaryListItemKey>Τηλέφωνο επικοινωνίας</SummaryListItemKey>
            <SummaryListItemValue>6941234567</SummaryListItemValue>
            <SummaryListItemAction>
              {' '}
              <Link>
                {' '}
                Αλλαγή <VisuallyHidden> τηλεφώνου </VisuallyHidden>
              </Link>
            </SummaryListItemAction>
          </SummaryListItem>
        </SummaryList>
      </TabsPanel>
      <TabsPanel {...panel('b')}>
        <Heading size="md" element="h3">
          Yποθέσεις
        </Heading>
        Περιεχόμενα υποθέσεων
      </TabsPanel>
      <TabsPanel {...panel('c')}>
        <Heading size="md" element="h3">
          Μηνύματα
        </Heading>
        {/* fill a random paragraph */}
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>
      </TabsPanel>
      <TabsPanel {...panel('d')}>
        <Heading size="md" element="h3">
          Ιστορικό
        </Heading>
        {/* fill a random paragraph */}
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>
      </TabsPanel>
    </Tabs>
  );
}

export default Default;
