import React from 'react';
import {
  Accordion,
  AccordionSection,
  AccordionSectionContent,
  AccordionSectionSummary,
  AccordionSectionSummaryHeading,
} from '@digigov/ui/content/Accordion';
import {
  SummaryList,
  SummaryListItem,
  SummaryListItemKey,
  SummaryListItemValue,
  SummaryListItemAction,
} from '@digigov/ui/content/SummaryList';
import { Hidden } from '@digigov/ui/layouts/Hidden';
import { Link } from '@digigov/ui/navigation/Link';
import {
  Tabs,
  TabsHeading,
  TabsList,
  useTabs,
} from '@digigov/ui/navigation/Tabs';
import { TabsListItem, TabsPanel } from '@digigov/ui/navigation/Tabs/auto';
import { Heading } from '@digigov/ui/typography/Heading';
import { Paragraph } from '@digigov/ui/typography/Paragraph';
import { VisuallyHidden } from '@digigov/ui/utils/VisuallyHidden';

export function UsingAccordion() {
  const { register, panel } = useTabs({ defaultOpen: 'a' });

  const StoixeiaContent = () => {
    return (
      <>
        <Heading size="md" element="h3">
          Στοιχεία πολίτη
        </Heading>
        <SummaryList>
          <SummaryListItem>
            <SummaryListItemKey>Όνομα</SummaryListItemKey>
            <SummaryListItemValue>Γιώργος Παπαδόπουλος</SummaryListItemValue>
            <SummaryListItemAction>
              <Link href="#">
                Αλλαγή <VisuallyHidden> ονόματος </VisuallyHidden>
              </Link>
            </SummaryListItemAction>
          </SummaryListItem>
          <SummaryListItem>
            <SummaryListItemKey>Ημ. Γέννησης</SummaryListItemKey>
            <SummaryListItemValue>11 Μαϊου 1990</SummaryListItemValue>
          </SummaryListItem>
          <SummaryListItem>
            <SummaryListItemKey>Τηλέφωνο επικοινωνίας</SummaryListItemKey>
            <SummaryListItemValue>6941234567</SummaryListItemValue>
            <SummaryListItemAction>
              <Link>
                Αλλαγή <VisuallyHidden> τηλεφώνου </VisuallyHidden>
              </Link>
            </SummaryListItemAction>
          </SummaryListItem>
        </SummaryList>
      </>
    );
  };
  const YpotheseisContent = () => {
    return (
      <>
        <Heading size="md" element="h3">
          Yποθέσεις
        </Heading>
        Περιεχόμενα υποθέσεων
      </>
    );
  };

  const MhnumataContent = () => {
    return (
      <>
        <Heading size="md" element="h3">
          Μηνύματα
        </Heading>
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>{' '}
      </>
    );
  };

  const IstorikoContent = () => {
    return (
      <>
        <Heading size="md" element="h3">
          Ιστορικό
        </Heading>
        <Paragraph>
          Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
          eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad
          minim veniam, quis nostrud exercitation ullamco laboris nisi ut
          aliquip ex ea commodo consequat. Duis aute irure dolor in
          reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
          pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
          culpa qui officia deserunt mollit anim id est laborum.
        </Paragraph>
      </>
    );
  };

  return (
    <>
      <Hidden xs sm>
        <Tabs>
          <TabsHeading size="md">Περιεχόμενα</TabsHeading>
          <TabsList>
            <TabsListItem {...register('a')}>Στοιχεία πολίτη</TabsListItem>
            <TabsListItem {...register('b')}>Yποθέσεις</TabsListItem>
            <TabsListItem {...register('c')}>Μηνύματα</TabsListItem>
            <TabsListItem {...register('d')}>Ιστορικό</TabsListItem>
          </TabsList>
          <TabsPanel {...panel('a')}>
            <StoixeiaContent />
          </TabsPanel>
          <TabsPanel {...panel('b')}>
            <YpotheseisContent />
          </TabsPanel>
          <TabsPanel {...panel('c')}>
            <MhnumataContent />
          </TabsPanel>
          <TabsPanel {...panel('d')}>
            <IstorikoContent />
          </TabsPanel>
        </Tabs>
      </Hidden>
      <Hidden mdUp>
        <Accordion summaryColor="secondary" dense>
          <AccordionSection open>
            <AccordionSectionSummary>
              <AccordionSectionSummaryHeading aria-controls="content1">
                Στοιχεία πολίτη
              </AccordionSectionSummaryHeading>
            </AccordionSectionSummary>
            <AccordionSectionContent id="content1">
              <StoixeiaContent />
            </AccordionSectionContent>
          </AccordionSection>
          <AccordionSection>
            <AccordionSectionSummary>
              <AccordionSectionSummaryHeading aria-controls="content2">
                Yποθέσεις
              </AccordionSectionSummaryHeading>
            </AccordionSectionSummary>
            <AccordionSectionContent id="content2">
              <YpotheseisContent />
            </AccordionSectionContent>
          </AccordionSection>
          <AccordionSection>
            <AccordionSectionSummary>
              <AccordionSectionSummaryHeading aria-controls="content3">
                Μηνύματα
              </AccordionSectionSummaryHeading>
            </AccordionSectionSummary>
            <AccordionSectionContent id="content3">
              <MhnumataContent />
            </AccordionSectionContent>
          </AccordionSection>
          <AccordionSection>
            <AccordionSectionSummary>
              <AccordionSectionSummaryHeading aria-controls="content4">
                Ιστορικό
              </AccordionSectionSummaryHeading>
            </AccordionSectionSummary>
            <AccordionSectionContent id="content4">
              <IstorikoContent />
            </AccordionSectionContent>
          </AccordionSection>
        </Accordion>
      </Hidden>
    </>
  );
}

export default UsingAccordion;
